@@ -9,7 +9,7 @@ package Error::Base;
 use 5.008008;
 use strict;
 use warnings;
-use version 0.77; our $VERSION = qv('v0.1.0');
+use version 0.77; our $VERSION = qv('v0.1.1');
 
 # Core modules
 use overload                    # Overload Perl operations
@@ -213,7 +213,6 @@ sub _trace {
 #           : -base     : string    : initial part of error message
 #           : -top      : integer   : starting backtrace frame
 #           : -quiet    : boolean   : TRUE for no backtrace at all
-#           : -$"       : string    : local list separator
 # Returns   : never
 # Throws    : $self     : die will stringify
 # See also  : _fuss(), crank(), cuss(), init()
@@ -242,26 +241,35 @@ sub _fuss {
     else {                                      # called as class method
         $self       = $self->new(@_);
     };
+    
     my $max         = 78;                       # maximum line length
+    my $message     ;                           # user-defined error message
+    my @lines       ;                           # to stringify $self
         
     # Collect all the texts into one message.
-    $self->{-msg}   = $self->_join_local(
+    $message        = $self->_join_local(
                         $self->{-base},
                         $self->{-type},
                         $self->{-pronto},
                     );
     
     # Late interpolate.    
-#~     ##### _fuss before:
-#~     ##### $self
-    $self->{-msg}   = $self->_late( $self->{-msg} );
-#~     ##### _fuss after:
-#~     ##### $self
+    $message        = $self->_late( $message );
     
     # If still no text in there, finally default.
-    if    ( not $self->{-msg}   ) {
-        $self->{-msg}   = 'Undefined error.';
+    if    ( not $message ) {
+        $message        = 'Undefined error.';
     }; 
+    $self->{-msg}   = $message;                 # keep for possible inspection
+
+    # Accumulate.
+    @lines          = ( $message );
+        
+    # Stack backtrace by default.
+    if ( not $self->{-quiet} ) {
+        my @trace       = $self->_trace( -top => $self->{-top} );
+        push @lines, @trace;
+    };
     
     # Optionally prepend some stuff.
     my $prepend     = q{};                      # prepended to first line
@@ -283,11 +291,19 @@ sub _fuss {
                         ;
     }; 
     
-    # First line is basic error text.
-    my $msg         = $self->_join_local(
-                        $prepend,
-                        $self->{-msg},
-                    );
+    @{ $self->{-lines} }    = $self->_join_local(
+                                $prepend,
+                                shift @lines
+                            );
+    push @{ $self->{-lines} }, map {
+                                    $self->_join_local(
+                                        $indent,
+                                        $_
+                                    )
+                                } @lines;
+    
+#~     ##### $self
+    return $self;
     
 #~     # Do something to control line length and deal with multi-line $msg.
 #~     my @temp        = split /\n/, $msg;         # in case it's multi-line
@@ -297,16 +313,6 @@ sub _fuss {
 #~     my $infix       = qq{\n} . $indent;
 #~        $msg         = join $infix, @temp;
     
-    $self->{-lines} = [ $msg ];                 # don't push; clear old @lines
-    
-    # Stack backtrace by default.
-    if ( not $self->{-quiet} ) {
-        my @trace       = $self->_trace( -top => $self->{-top} );
-        push @{ $self->{-lines} }, map { $indent . $_ } @trace;
-    };
-    
-#~     ##### $self
-    return $self;
 }; ## _fuss
 
 #=========# CLASS OR OBJECT METHOD
@@ -335,20 +341,15 @@ sub cuss{
 #       
 # Purpose   : Like builtin join() but with local list separator.
 # Parms     : @_        : strings to join
-# Reads     : -$"       : like $"   : $self parm    : default q{ }
 # Returns   : $string   : joined strings
 # Throws    : ____
 # See also  : init()
 # 
-# Buitin join() does not take $" (or anything else) by default; 
-#   and in any case $" eq q{} by default. 
-# Caller can set $self->{'-$"'} in any method that invokes init(). 
+# Buitin join() does not take $" (or anything else) by default.
+# We splice out empty strings to avoid useless runs of spaces.  
 # 
 sub _join_local {
     my $self        = shift;
-    local $"        = $self->{'-$"'};
-    die 'Error::Base internal error: undefined local list separator: ', $!
-        if not defined $";
     my @parts       = @_;
     
     # Splice out empty strings. 
@@ -436,9 +437,6 @@ sub init {
     if    ( not defined $self->{-top}   ) {
         $self->{-top}   = 2;                # skip frames internal to E::B
     }; 
-    if    ( not defined $self->{q'-$"'} ) {
-        $self->{q'-$"'} = q{ };             # local list separator
-    }; 
         
     return $self;
 }; ## init
@@ -514,14 +512,17 @@ sub _late {
             q*#--------------------------------------------------------#*,
             q*# START EVAL                                              *,
             q**,
+            q*my $self  = $Error::Base::Late::self;*,
+            q**,
         ;
         
         # Unpack all appropriate k/v pairs into their own lexical variables... 
         
         # Each key includes leading sigil.
         my @keys    = grep { /^[\$\@%]/ } keys %$Error::Base::Late::self;
-        return $Error::Base::Late::in 
-            unless @keys;       # no interpolation today
+        return $Error::Base::Late::in   # abort if not interpolating today
+#~             unless ( @keys or $Error::Base::Late::in =~ /\$self/ );
+            unless ( @keys );
         my $key     ;  # placeholder includes sigil!
         my $val     ;  # value to be interpolated
         my $rt      ;  # builtin 'ref' returns (unwanted) class of blessed ref
@@ -594,11 +595,12 @@ $Error::Base::Late::out     = eval
 $Error::Base::Late::eval_code
 Heredoc03_Y0uMaYFiReWHeNReaDYGRiDLeY
         
-        warn "Error::Base internal warning: in _late eval: '$@" if $@;
+        warn "Error::Base internal warning: in _late eval: $@" if $@;
         
 #~         ##### CASE
 #~         ##### $Error::Base::Late::self
 #~         ##### $Error::Base::Late::in
+#~         ##### @Error::Base::Late::code
 #~         ##### $Error::Base::Late::eval_code
 #~         ##### $@
     
@@ -624,7 +626,7 @@ Error::Base - Simple structured errors with full backtrace
 
 =head1 VERSION
 
-This document describes Error::Base version v0.1.0
+This document describes Error::Base version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -636,7 +638,7 @@ This document describes Error::Base version v0.1.0
     $err->crash;                                # as object method
     
     my $err     = Error::Base->new(
-                    'Foo error',                # odd arg is error text
+                        'Foo error',            # odd arg is error text
                     -quiet    => 1,             # no backtrace
                     grink     => 'grunt',       # store somethings
                     puppy     => 'dog',         # your keys, no leading dash 
@@ -647,15 +649,21 @@ This document describes Error::Base version v0.1.0
     my $err = Error::Base->crank('Me!');        # also a constructor
     
     eval{ Error::Base->crash( 'car', -foo => 'bar' ) }; 
-    my $err     = $@ if $@;         # catch and examine the object
+    my $err     = $@ if $@;         # catch and examine the full object
     
     my $err     = Error::Base->new(
                     -base       => 'File handler error:',
                     _openerr    => 'Couldn\t open $file for $op',
                 );
-    $err->crash(
-        -type
-    );
+    {
+        my $file = 'z00bie.xxx';    # uh-oh, variable out of scope for new()
+        open my $fh, '<', $file
+            or $err->crash(
+                -type       => $err->{_openerr},
+                '$file'     => $file,
+                '$op'       => 'reading',
+            );                      # late interpolation to the rescue
+    }
 
 =head1 DESCRIPTION
 
@@ -684,19 +692,14 @@ You are not required to subclass it.
 
 =head2 new()
 
-    my $err     = Error::Base->new('Foo');      # constructor
-    my $err     = Error::Base->new(             # with named args
+    my $err     = Error::Base->new;             # constructor
+    my $err     = Error::Base->new(
+                        'bartender:',           # lone string first okay
                     -base       => 'Bar error:',
                     -quiet      => 1,
                     -top        => 3,
-                    -prepend    => '@! Globalcorpcoapp:',
+                    -prepend    => '@! Black Tie Lunch:',
                     -indent     => '@!                 ',
-                    foo         => bar,
-                );
-    my $err     = Error::Base->new(             # okay to pass both
-                        'bartender:'            # lone string...
-                    -base   => 'Bar error:',    # ... and named args
-                    -type   => 'last call',     # be more specific
                     _beer   => 'out of beer',   # your private attribute(s)
                 );
 
@@ -705,35 +708,40 @@ returning a new object based on an old one. You do have some freedom in how
 you call, though. 
 
 Called with an even number of args, they are all considered key/value pairs. 
-Keys with leading dash (C<'-'>) are reserved for use by Error::Base; 
-all others are free to use as you see fit. Error message text is constructed 
-as a single string.
+Keys with leading dash (C<'-'>) are reserved for use by Error::Base;
+keys led by a Perlish sigil (C<=~ /^[\$\@%]/>) trigger 
+L<late interpolation|/LATE INTERPOLATION>;
+all other keys are free to use as you see fit. 
+Error message text is constructed as a single string.
 
 Called with an odd number of args, the first arg is shifted off and appended
 to the error message text. This shorthand may be offensive to some; in which 
-case, don't do that. Instead, pass -base, -type, or both. 
+case, don't do that. Instead, pass C<< -base >>, C<< -type >>, or both. 
 
 You may stash any arbitrary data inside the returned object (during 
 construction or later) and do whatever you like with it. You might choose to 
 supply additional optional texts for later access. 
 
+Stringification is overridden on objects of this class. So, if you attempt to 
+print the object, or perform an operation that causes perl to want to treat 
+it as a string, you will get the printable error message. If you prefer to 
+examine the object internally, access its hash values; or dump it using 
+L<Data::Dumper|Data::Dumper>, L<Devel::Comments|Devel::Comments>, or 
+L<Test::More|Test::More>::explain().
+
 See L</PARAMETERS>.
 
 =head2 crash()
 
     Error::Base->crash('Sanity check failed');  # as class method
-    my $err = Error::Base->crash('Flat tire:'); # also a constructor
     $err->crash;                                # as object method
-    $err->crash(        # all the same args are okay in crash() as in new()
-                'bartender: '
-            -base   => 'Bar error:',
-        );
-    eval{ $err->crash }; 
-    my $err     = $@ if $@;         # catch and examine the object
+        # all the same args are okay in crash() as in new()
+    eval{ $err->crash };                        # trap...
+    print STDERR $@ if $@;                      # ... and examine the object
 
 C<crash()> and other public methods may be called as class or object methods. 
 If called as a class method, then C<new()> is called internally. Call C<new()>
-yourself first if you want to call C<crash()> as an object method. 
+first if you want to call C<crash()> as an object method. 
 
 C<crash()> is a very thin wrapper, easy to subclass. It differs from similar 
 methods in that instead of returning its object, it C<die()>-s with it. 
@@ -741,16 +749,11 @@ If uncaught, the error will stringify; if caught, the entire object is yours.
 
 =head2 crank()
 
-    Error::Base->crank('More gruel!');          # as class method
-    $err->crank;                                # as object method
-    my $err = Error::Base->crank('Me!');        # also a constructor
+    $err->crank( -type => 'Excessive boxes' ) if $box > $max;
+
 
 This is exactly like C<crash()> except that it C<warn()>s instead of 
-C<die()>-ing. Therefore it can also usefully be used as a constructor of an 
-object for later use. 
-
-C<crank()> is also a very thin wrapper. You may subclass it; you may trap 
-the entire object or let it stringify to STDERR.
+C<die()>-ing. Therefore you may easily recover the object for later use. 
 
 =head2 cuss()
 
@@ -771,14 +774,13 @@ error will be thrown without the bother of actually catching C<crash()>.
 
     $err->init(@args);
 
-Probably, it is not useful to call this object method directly. Perhaps you 
-might subclass it or call it from within your subclass constructor. 
 The calling conventions are exactly the same as for the other public methods. 
 
-C<init()>, is called on a newly constructed object, as is conventional. 
+C<init()> is called on a newly constructed object, as is conventional. 
 If you call it a second time on an existing object, new C<@args> will 
 overwrite previous values. Internally, when called on an existing object,
-C<crash()>, C<crank()>, and C<cuss()> each call C<init()>. 
+C<crash()>, C<crank()>, and C<cuss()> each call C<init()>. When these are 
+called as class methods, they call C<new()>, which calls C<init()>.
 
 Therefore, the chief distinction between calling as class or object method is 
 that if you call new() first then you can separate the definition of your 
@@ -791,14 +793,7 @@ All parameter names begin with a leading dash (C<'-'>); please choose other
 names for your private keys. 
 
 If the same parameter is set multiple times, the most recent argument 
-completely overwrites the previous: 
-
-    my $err     = Error::Base->new( -top    => 3, );
-        # -top is now 3
-    $err->cuss(  -top    => 0, );
-        # -top is now 0
-    $err->crank( -top    => 1, );
-        # -top is now 1
+completely overwrites the previous value. 
 
 You are cautioned that deleting keys may be unwise. 
 
@@ -806,9 +801,6 @@ You are cautioned that deleting keys may be unwise.
 
 I<scalar string>
 
-    $err->crash;                        # emits 'Undefined error'
-    $err->crash( -base => 'Bar');       # emits 'Bar'
-
 The value of C<< -base >> is printed in the first line of the stringified 
 error object after a call to C<crash()>, C<crank()>, or C<cuss()>. 
 
@@ -816,15 +808,8 @@ error object after a call to C<crash()>, C<crank()>, or C<cuss()>.
 
 I<scalar string>
 
-    $err->crash( 
-            -type   => 'last call'
-        );                              # emits 'last call'
-    $err->crash(
-            -base   => 'Bar',
-            -type   => 'last call',
-        );                              # emits 'Bar last call'
-
 This parameter is provided as a way to express a subtype of error. 
+It is appended to C<< -base >>. 
 
 =head2 -pronto
 
@@ -832,30 +817,20 @@ I<scalar string>
 
     $err->crash( 'Pronto!' );           # emits 'Pronto!'
     $err->crash(
-                'Pronto!',
-            -base   => 'Bar',
-            -type   => 'last call',
-        );                              # emits 'Bar last call Pronto!'
-    $err->crash(
-            -base   => 'Bar',
-            -type   => 'last call',
             -pronto => 'Pronto!',
-        );                              # same thing
+    );                                  # same thing
 
 As a convenience, if the number of arguments passed in is odd, then the first 
-arg is shifted off and appnended to the error message. This is done to 
-simplify writing one-off, one-line sanity checks:
+arg is shifted off and appended to the error message 
+after C<< -base >> and C<< -type >>. 
+This is done to simplify writing one-off, one-line sanity checks:
 
     open( my $in_fh, '<', $filename )
         or Error::Base->crash("Couldn't open $filename for reading.");
 
-It is expected that each message argument be a single scalar. If you need 
+TODO: It is expected that each message argument be a single scalar. If you need 
 to pass a multi-line string then please embed escaped newlines (C<'\n'>). 
 
-=head2 -key
-
-This feature has been replaced by L</LATE INTERPOLATION>.
-
 =head2 -quiet
 
 I<scalar boolean> default: undef
@@ -863,28 +838,16 @@ I<scalar boolean> default: undef
     $err->crash( -quiet         => 1, );        # no backtrace
 
 By default, you get a full stack backtrace. If you want none, set this 
-parameter. Only C<< -msg >> will be emitted. 
+parameter. Only error text will be emitted. 
 
 =head2 -top
 
 I<scalar unsigned integer> default: 2
 
-    $err->crash( -top           => 0, );        # really full backtrace
+By default, stack frames internal to Error::Base are not traced. 
+Set this parameter to adjust how many frames to discard. 
 
-By default, you get a full stack backtrace: "full" meaning, from the point of
-invocation. Some stack frames are added by the process of crash()-ing itself; 
-by default, these are not seen. If you want more or fewer frames you may set 
-this parameter. 
-
-Beware that future implementations may change the number of stack frames 
-added internally by Error::Base; and also you may see a different number of 
-frames if you subclass, depending on how you do that. The safe way: 
-
-    my $err     = Error::Base->new('Foo');      # construct object
-    $err->{ -top => ($err->{-top})++ };         # drop the first frame
-    $err->crash();
-
-This is ugly and you may get a convenience method in future. 
+TODO: A more elegant interface. 
 
 =head2 -prepend
 
@@ -898,154 +861,23 @@ I<scalar string> default: first char of -prepend, padded with spaces to length
 
 I<scalar string> default: undef
 
-    my $err     = Error::Base->new(
-                    -prepend    => '#! Globalcorpcoapp:',
-                );
-    $err->crash ('Boy Howdy!');
-        # emits '@! Globalcorpcoapp: Boy Howdy!
-        #        @                   in main::fubar at line 42    [test.pl]'
-
-Any string passed to C<< -prepend >> will be prepended to the first line only 
-of the formatted error message. If C<< -indent >> is defined then that will be
-prepended to all following lines. If C<< -indent >> is undefined then it will 
-be formed from the first character only of C<< -prepend >>, padded with spaces
-to the length of C<< -prepend >>. 
-C<< -prepend_all >> will be prepended to all lines. 
+The value of C<< -prepend >> is prepended to the first line of error text; 
+C<< -indent >> to all others. If given, C<< -prepend_all >> overrides the 
+other parameters and is prepended to all lines. 
 
 This is a highly useful feature that improves readability in the middle of a 
 dense dump. So in future releases, the default may be changed to form 
 C<< -prepend >> in some way for you if not defined. If you are certain you 
 want no prepending or indentation, pass the empty string, C<q{}>.
 
-=head2 -$"
+=head2 LATE INTERPOLATION
 
-I<scalar string> default: q{ }
-
-    my $err     = Error::Base->new(
-                    -base   => 'Bar',
-                    -type   => 'last call',
-                );
-    $err->crash(
-                'Pronto!',
-        );                              # emits 'Bar last call Pronto!'
-    $err->crash(
-                'Pronto!',
-            '-$"'   => '=',
-        );                              # emits 'Bar=last call=Pronto!'
-
-If you interpolate an array into a double-quoted literal string, perl will 
-join the elements with C<$">. Similarly, if you late interpolate an array into
-an error message part, Error::Base will join the elements with the value of 
-C<< $self->{'-$"'} >>. This does not have any effect on the Perlish C<$">. 
-Similarly, C<$"> is ignored when Error::Base stirs the pot. 
-
-Also, message parts themselves are joined with C<< $self->{'-$"'} >>. 
-The default is a single space. This helps to avoid the unsightly appearance of 
-words stuck together because you did not include enough space in your args. 
-Empty elements are spliced out to avoid multiple consecutive spaces. 
-
-Note that C<< '-$"' >> is a perfectly acceptable hash key but it must be 
-quoted, lest trains derail in Vermont. The fat comma does not help. 
-
-=head1 LATE INTERPOLATION
-
-Recall that all methods, on init(), pass through all arguments as key/value 
-pairs in the error object. Except for those parameters reserved by the class 
-API (by convention of leading dash), these are preserved unaltered. 
-
-    my $err     = Error::Base->new(
-                    -base   => 'Panic:',
-                    -type   => 'lost my $foo.',
-                );
-    $err->crash(
-                'Help!',
-            '$foo'  => 'hat',
-        );      # emits 'Panic: lost my hat. Help!'
-    
-    my $err     = Error::Base->new(
-                    -base   => 'Sing:',
-                    '@favs' => [qw/ schnitzel with noodles /],
-                );
-    $err->crash(
-            -type   => 'My favorite things are @favs.',
-        );      # emits 'Sing: My favorite things are schnitzel with noodles.'
-
-If we want to emit an error including information only available within a 
-given scope we can interpolate it then and there with a double-quoted literal: 
-
-    open( my $in_fh, '<', $filename )
-        or Error::Base->crash("Couldn't open $filename for reading.");
-
-This doesn't work if we want to declare lengthy error text well ahead of time: 
-
-    my $err     = Error::Base->new(
-                    -base   => 'Up, Up and Away:',
-                    -type   => "FCC wardrobe malfunction of $jackson",
-                );
-    sub call_ethel {
-        my $jackson     = 'Janet';
-        $err->crank;
-    };                  # won't work; $jackson out of scope for -type
-
-What we need is B<late interpolation>, which Error::Base provides. 
-
-When we have the desired value in scope, we simply pass it as the value 
-to a key matching the I<placeholder> C<$jackson>: 
-
-    my $err     = Error::Base->new(
-                    -base   => 'Up, Up and Away:',
-                    -type   => 'FCC wardrobe malfunction of $jackson',
-                );
-    sub call_ethel {
-        my $jackson     = 'Janet';
-        $err->crank( '$jackson' => \$jackson );
-    };                  # 'Up, Up and Away: FCC wardrobe malfunction of Janet'
-
-B<Note> that the string passed to C<new()> as the value of C<< -type >> is now 
-single quoted, which avoids a futile attempt to interpolate immediately. Also, 
-a reference to the I<variable> C<$jackson> is passed as the value of the 
-I<key> C<'$jackson'>. The key is quoted to avoid it being parsed as a variable. 
-
-    my $err     = Error::Base->new(
-                        'right here in $cities[$i].',
-                    -base   => 'Our $children{'who'} gonna have',
-                    -type   => q/$self->{'_what'}/,
-                );
-    $err->crash(
-            _what       => 'trouble:'
-            '%children' => { who => 'children\'s children' },
-            '@cities'   => [ 'Metropolis', 'River City', 'Gotham City' ],
-            '$i'        => 1,
-        );          # you're the Music Man
-
-You may use scalar or array placeholders, signifying them with the usual 
-sigils. Although you pass a reference, use the appropriate 
-C<$>, C<@> or C<%> sigil to lead the corresponding key. As a convenience, you 
-may pass simple scalars directly. (It's syntactically ugly to pass a 
-reference to a literal scalar.) Any value that is I<not> a 
-reference will be late-interpolated directly; anything else will be 
-deferenced (once). 
-
-This is Perlish interpolation, only delayed. You can interpolate escape 
-sequences and anything else you would in a double-quoted string. You can pass 
-a reference to a package variable; but do so against a simple key such as 
-C<'$aryref'>. 
-
-As a further convenience, you may interpolate a value from the error object 
-itself. In the previous example, 
-C<< -type >> is defined as C<< '$self->{_what}' >> 
-(please note the single quotes). And also, 
-C<< _what >> is defined as C<< 'trouble:' >>. 
-When late-interpolated, C<< -type >> expands to C<< 'trouble:' >>. 
-Note that Error::Base has no idea what you have called your error object 
-(perhaps '$err'); use the placeholder C<< '$self' >> at all times. 
-
-Don't forget to store your value against the appropriate key! 
-This implementation of this feature does not peek into your pad. 
-You may not receive an 'uninitialized' warning if a value is missing. 
-However, no late interpolation will be attempted if I<no> keys are stored, 
-prefixed with C<$>, C<@> or C<%>. The literal sigil will be printed. 
-So if you don't like this feature, don't use it. 
+It is possible to interpolate a variable that is I<not in scope> 
+into error message text. This is triggered by passing the value against a 
+key whose leading character is a Perlish sigil, one of C<$@%>. 
+Enclose the text (including placeholders) in single quotes. 
+For a detailed explanation, 
+see the L<Cookbook|Error::Base::Cookbook/Late Interpolation>.
 
 =head1 RESULTS
 
@@ -1053,10 +885,11 @@ Soon, I'll write accessor methods for all of these. For now, rough it.
 
 =head2 -msg
 
-I<scalar string> default: 'Undefined error'
+I<scalar string> default: 'Undefined error.'
 
-The error message, expanded, without -prepend or backtrace. An empty message 
-is not allowed; if none is provided by any means, 'Undefined error' emits. 
+The error message, expanded, without C<< -prepend >> or backtrace. 
+An empty message is not allowed; if none is provided by any means, 
+'Undefined error.' emits. 
 
 =head2 -lines
 
@@ -1099,44 +932,11 @@ do so, successfully or not, please be so kind as to notify.
 
 Many error-related modules are available on CPAN. Some do bizarre things. 
 
-L<Error> is self-deprecated in its own POD as "black magic"; 
-which recommends L<Exception::Class> instead.
-
-L<Exception> installs a C<< $SIG{__DIE__} >> handler that converts text 
-passed to C<die> into an exception object. It permits environment variables 
-and setting global state; and implements a C<try> syntax. This module may be 
-closest in spirit to Error::Base. 
-For some reason, I can't persuade C<cpan> to find it. 
-
-L<Carp> is well-known and indeed, does a full backtrace with C<confess()>. 
-The better-known C<carp()> may be a bit too clever and in any case, the dump 
-is not formatted to my taste. The module is full of global variable settings. 
-It's not object-oriented and an error object can't easily be pre-created.  
-
-The pack leader seems to be L<Exception::Class>. Error::Base differs most 
-strongly in that it has a shorter learning curve (since it does much less); 
-confines itself to error message emission (catching errors is another job); 
-and does a full stack backtrace dump by default. Less code may also be 
-required for simple tasks. 
-
-To really catch errors, I like L<Test::Trap> ('block eval on steroids'). 
-It has a few shortcomings but is extremely powerful. I don't see why its use 
-should be confined to testing. 
-
-The line between emitting a message and catching it is blurred in many 
-related modules. I did not want a jack-in-the-box object that phoned home if 
-it was thrown under a full moon. The only clever part of an Error::Base 
-object is that it stringifies. 
-
-It may be true to say that many error modules seem to I<expect> to be caught. 
-I usually expect my errors to cause all execution to come to a fatal, 
-non-recoverable crash. Oh, yes; I agree it's sometimes needful to catch such 
-errors, especially during testing. But if you're regularly throwing and 
-catching, the term 'exception' may be appropriate but perhaps not 'error'. 
+L<Exception::Class|Exception::Class>, L<Error|Error>, L<Exception|Exception>, L<Carp|Carp>, L<Test::Trap|Test::Trap>.
 
 =head1 INSTALLATION
 
-This module is installed using L<Module::Build>. 
+This module is installed using L<Module::Build|Module::Build>. 
 
 =head1 DIAGNOSTICS
 
@@ -1156,12 +956,6 @@ You probably mis-set C<< -top >>, rational values of which are perhaps C<0..9>.
 You do I<not> have to pass paired arguments to most public methods. 
 Perhaps you passed an odd number of args to a private method. 
 
-=item C<< Error::Base internal error: undefined local list separator: >>
-
-C<init()> sets C<< $self->{'-$"'} = q{ } >> by default; you may also set it 
-to another value. If you want your message substrings tightly joined, 
-set C<< $self->{'-$"'} = q{} >>; don't undefine it. 
-
 =item C<< Error::Base internal error: bad reftype: >>
 
 You attempted to late-interpolate a reference other than to a scalar, array, or hash. Don't pass such references as values to any key with the wrong sigil. 
@@ -1176,11 +970,11 @@ Error::Base requires no configuration files or environment variables.
 
 There are no non-core dependencies. 
 
-L<version> 0.94                 # Perl extension for Version Objects
+L<version|version> 0.94                 # Perl extension for Version Objects
 
-L<overload>                     # Overload Perl operations
+L<overload|overload>                    # Overload Perl operations
 
-L<Scalar::Util>                 # General-utility scalar subroutines
+L<Scalar::Util|Scalar::Util>            # General-utility scalar subroutines
 
 This module should work with any version of perl 5.8.8 and up. 
 
@@ -1190,7 +984,7 @@ None known.
 
 =head1 BUGS AND LIMITATIONS
 
-This is a very early release. Reports will be warmly welcomed. 
+This is an early release. Reports and suggestions will be warmly welcomed. 
 
 Please report any bugs or feature requests to
 C<bug-error-base@rt.cpan.org>, or through the web interface at
